import numpy as np


def luminanceD65(rgb: np.ndarray) -> np.float64:
    """
    Compute the luminance value of the specified linear RGB values
    according to the D65 white point.

    @param rgb(np.ndarray): sRGB image

    @returns The luminance value
    """
    return np.float64(rgb @ [0.2126, 0.7152, 0.0722])


# Task 1:   Implement some kind of noticeable image manipulation in this function
#           e.g. channel manipulation, filter you already know, drawings on the image etc.
def myFirstImageManipulation(img) -> np.ndarray:
    """
    Convert each pixel in the input image using the D65 luminance formula.

    This function takes a NumPy array `img` as input and returns a new array with
    each pixel value replaced by its corresponding D65 luminance value. The output
    array maintains the same dimensions and data type as the input array, but each
    pixel is processed through this specific transformation.

    Parameters:
    - img (ndarray): The input image data array of shape (height, width).

    Returns:
    - ndarray: An array where each pixel has been replaced by its D65
        luminance value from the original image.
    """
    result = img.copy()

    for x in range(0, result.shape[0]):
        for y in range(0, result.shape[1]):

            result[x][y] = luminanceD65(img[x][y])

    return result


# Task 2:   Return the basic image properties to the console:
#           width, height,
#           the color of the first pixel of the image,
#           Color of the first pixel in the second row
#           Color of the first pixel in the second column
#           This function should work for images with three channels
def imageSize(img: np.ndarray) -> list[int]:
    """Get the height and width dimensions of an image array.

    Args:
        img (np.ndarray): A numpy array representing the image.

    Returns:
        list[int]: A two-element list containing [height, width] dimensions of the image.

    Note:
        The function works for any multi-dimensional numpy array. It returns
        a list with the first two dimensions regardless of whether they are 2D or higher.
    """
    return [img.shape[0], img.shape[1]]


def getPixelColor(img):
    """
    Retrieve color information from specific pixels in an image array.

    This function processes an RGB image array and returns a list of color values
    based on predefined positions. It is designed to handle multi-channel images,
    extracting information such as first pixel of each row, specific channels,
    and other notable points within the image data.

    Parameters:
        img (np.ndarray): The input image data array containing RGB or grayscale values.

    Returns:
        list: A structured list of color values extracted from different positions
              in the image. This includes colors from specified rows, columns,
              and channels where applicable.
    """
    return [img[0][1], img[1][0]]


# Task 3:   Separate the given channels of a colour image in this function and return it as separate image
def returnChannel(img: np.ndarray, channel: int) -> np.ndarray:
    """
    Splits an image into a separate channel or keeps only the specified color channel.

    Parameters:
        - img: Input np.ndarray (required). This should be a color image array in RGB format.
          If it's grayscale, this method might not work correctly as it expects three channels.
        - channel: int (required). The index of the channel to keep. It can be 0 for red, 1 for green, or 2 for blue.

    Returns:
        - np.ndarray: A new image array where only the specified color channel is non-zero,
          and other channels are zeroed out.
    """
    result = img.copy()

    for x in range(0, result.shape[0]):
        for y in range(0, result.shape[1]):
            for c in range(0, 3):
                if c == channel:
                    continue

                result[x][y][c] = 0

    return result
